<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ToolBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Icon Size:</source>
        <translation>アイコンサイズ:</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Pixel</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Options Toolbar</source>
        <translation>オプションツールバー</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Shortcut Prefix Character:</source>
        <translation>ショートカット前置文字:</translation>
    </message>
</context>
<context>
    <name>ToolBarPreferences</name>
    <message>
        <location filename="../ToolBarPreferences.js" line="+30"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Toolbars</source>
        <translation>ツールバー</translation>
    </message>
</context>
</TS>
